@@ -13,6 +13,7 @@ plugins="$3"
 tmp_dir="$4"
 recipe_file="$5"
 report_file="$6"
+debug_mode="$7"
 
 create_venv $task_id $datahub_version $plugins $tmp_dir
 
@@ -24,8 +25,14 @@ else
   report_option=""
 fi
 
+if [ "$debug_mode" == "true" ]; then 
+  debug_option="--debug"
+else
+  debug_option=""
+fi;
+
 # Execute DataHub recipe, based on the recipe id. 
-echo "datahub ingest run -c ${recipe_file} ${report_option}"
+echo "datahub ${debug_option} ingest run -c ${recipe_file} ${report_option}"
 if (datahub ingest run -c "${recipe_file}" ${report_option}); then
   exit 0
 else
