@@ -18,8 +18,9 @@ import asyncio
 import logging
 import nest_asyncio
 
-from typing import Dict, List
+from typing import Any, Dict, List
 from acryl.executor.common.config import ConfigModel
+from acryl.executor.execution.executor import Executor
 from acryl.executor.report.execution_report import ExecutionReport
 from acryl.executor.context.executor_context import ExecutorContext
 from acryl.executor.context.execution_context import ExecutionContext
@@ -45,7 +46,7 @@ class DefaultExecutorConfig(ConfigModel):
 """
 Executes a Task Execution Request 
 """
-class DefaultExecutor:
+class DefaultExecutor(Executor):
     id: str 
 
     # Execution Event Loop
@@ -58,7 +59,7 @@ class DefaultExecutor:
     # Tasks
     task_registry: TaskRegistry = TaskRegistry()
     task_instances: Dict[str, Task] = {}
-    task_futures: Dict[str, List[any]] = {} 
+    task_futures: Dict[str, List[Any]] = {}
 
     # Secret Stores 
     secret_stores: List[SecretStore] = []
